==> three-0.133.1.jar: META-INF/resources/webjars/three/0.133.1/examples/jsm/renderers/nodes/Nodes.js <==
// core
import ArrayInputNode from './core/ArrayInputNode.js';
import AttributeNode from './core/AttributeNode.js';
import CodeNode from './core/CodeNode.js';
import ConstNode from './core/ConstNode.js';
import ContextNode from './core/ContextNode.js';
import ExpressionNode from './core/ExpressionNode.js';
import FunctionCallNode from './core/FunctionCallNode.js';
import FunctionNode from './core/FunctionNode.js';
import InputNode from './core/InputNode.js';
import Node from './core/Node.js';
import NodeAttribute from './core/NodeAttribute.js';
import NodeBuilder from './core/NodeBuilder.js';
import NodeCode from './core/NodeCode.js';
import NodeFrame from './core/NodeFrame.js';
import NodeFunctionInput from './core/NodeFunctionInput.js';
import NodeKeywords from './core/NodeKeywords.js';
import NodeSlot from './core/NodeSlot.js';
import NodeUniform from './core/NodeUniform.js';
import NodeVar from './core/NodeVar.js';
import NodeVary from './core/NodeVary.js';
import PropertyNode from './core/PropertyNode.js';
import StructNode from './core/StructNode.js';
import StructVarNode from './core/StructVarNode.js';
import TempNode from './core/TempNode.js';
import VarNode from './core/VarNode.js';
import VaryNode from './core/VaryNode.js';

// accessors
import CameraNode from './accessors/CameraNode.js';
import MaterialNode from './accessors/MaterialNode.js';
import MaterialReferenceNode from './accessors/MaterialReferenceNode.js';
import ModelNode from './accessors/ModelNode.js';
import ModelViewProjectionNode from './accessors/ModelViewProjectionNode.js';
import NormalNode from './accessors/NormalNode.js';
import Object3DNode from './accessors/Object3DNode.js';
import PointUVNode from './accessors/PointUVNode.js';
import PositionNode from './accessors/PositionNode.js';
import ReferenceNode from './accessors/ReferenceNode.js';
import UVNode from './accessors/UVNode.js';

// inputs
import ColorNode from './inputs/ColorNode.js';
import FloatNode from './inputs/FloatNode.js';
import Matrix3Node from './inputs/Matrix3Node.js';
import Matrix4Node from './inputs/Matrix3Node.js';
import TextureNode from './inputs/TextureNode.js';
import Vector2Node from './inputs/Vector2Node.js';
import Vector3Node from './inputs/Vector3Node.js';
import Vector4Node from './inputs/Vector4Node.js';

// display
import ColorSpaceNode from './display/ColorSpaceNode.js';
import NormalMapNode from './display/NormalMapNode.js';

// math
import MathNode from './math/MathNode.js';
import OperatorNode from './math/OperatorNode.js';

// lights
import LightContextNode from './lights/LightContextNode.js';
import LightNode from './lights/LightNode.js';
import LightsNode from './lights/LightsNode.js';

// utils
import JoinNode from './utils/JoinNode.js';
import SplitNode from './utils/SplitNode.js';
import SpriteSheetUVNode from './utils/SpriteSheetUVNode.js';
import TimerNode from './utils/TimerNode.js';

// procedural
import CheckerNode from './procedural/CheckerNode.js';

// core
export * from './core/constants.js';

// functions
export * from './functions/BSDFs.js';
export * from './functions/EncodingFunctions.js';
export * from './functions/MathFunctions.js';

// consts
export * from './consts/MathConsts.js';

// materials
export * from './materials/Materials.js';

export {
	// core
	ArrayInputNode,
	AttributeNode,
	CodeNode,
	ConstNode,
	ContextNode,
	ExpressionNode,
	FunctionCallNode,
	FunctionNode,
	InputNode,
	Node,
	NodeAttribute,
	NodeBuilder,
	NodeCode,
	NodeFrame,
	NodeFunctionInput,
	NodeKeywords,
	NodeSlot,
	NodeUniform,
	NodeVar,
	NodeVary,
	PropertyNode,
	StructNode,
	StructVarNode,
	TempNode,
	VarNode,
	VaryNode,

	// accessors
	CameraNode,
	MaterialNode,
	MaterialReferenceNode,
	ModelNode,
	ModelViewProjectionNode,
	NormalNode,
	Object3DNode,
	PointUVNode,
	PositionNode,
	ReferenceNode,
	UVNode,

	// inputs
	ColorNode,
	FloatNode,
	Matrix3Node,
	Matrix4Node,
	TextureNode,
	Vector2Node,
	Vector3Node,
	Vector4Node,

	// display
	ColorSpaceNode,
	NormalMapNode,

	// math
	MathNode,
	OperatorNode,

	// lights
	LightContextNode,
	LightNode,
	LightsNode,

	// utils
	JoinNode,
	SplitNode,
	SpriteSheetUVNode,
	TimerNode,

	// procedural
	CheckerNode
};

==> three-0.135.0.jar: META-INF/resources/webjars/three/0.135.0/examples/jsm/renderers/nodes/Nodes.js <==
// core
import ArrayInputNode from './core/ArrayInputNode.js';
import AttributeNode from './core/AttributeNode.js';
import BypassNode from './core/BypassNode.js';
import CodeNode from './core/CodeNode.js';
import ContextNode from './core/ContextNode.js';
import ExpressionNode from './core/ExpressionNode.js';
import FunctionCallNode from './core/FunctionCallNode.js';
import FunctionNode from './core/FunctionNode.js';
import InputNode from './core/InputNode.js';
import Node from './core/Node.js';
import NodeAttribute from './core/NodeAttribute.js';
import NodeBuilder from './core/NodeBuilder.js';
import NodeCode from './core/NodeCode.js';
import NodeFrame from './core/NodeFrame.js';
import NodeFunctionInput from './core/NodeFunctionInput.js';
import NodeKeywords from './core/NodeKeywords.js';
import NodeUniform from './core/NodeUniform.js';
import NodeVar from './core/NodeVar.js';
import NodeVary from './core/NodeVary.js';
import PropertyNode from './core/PropertyNode.js';
import TempNode from './core/TempNode.js';
import VarNode from './core/VarNode.js';
import VaryNode from './core/VaryNode.js';

// accessors
import CameraNode from './accessors/CameraNode.js';
import MaterialNode from './accessors/MaterialNode.js';
import MaterialReferenceNode from './accessors/MaterialReferenceNode.js';
import ModelNode from './accessors/ModelNode.js';
import ModelViewProjectionNode from './accessors/ModelViewProjectionNode.js';
import NormalNode from './accessors/NormalNode.js';
import Object3DNode from './accessors/Object3DNode.js';
import PointUVNode from './accessors/PointUVNode.js';
import PositionNode from './accessors/PositionNode.js';
import ReferenceNode from './accessors/ReferenceNode.js';
import SkinningNode from './accessors/SkinningNode.js';
import UVNode from './accessors/UVNode.js';

// inputs
import ColorNode from './inputs/ColorNode.js';
import FloatNode from './inputs/FloatNode.js';
import IntNode from './inputs/IntNode.js';
import Matrix3Node from './inputs/Matrix3Node.js';
import Matrix4Node from './inputs/Matrix3Node.js';
import TextureNode from './inputs/TextureNode.js';
import Vector2Node from './inputs/Vector2Node.js';
import Vector3Node from './inputs/Vector3Node.js';
import Vector4Node from './inputs/Vector4Node.js';

// display
import ColorSpaceNode from './display/ColorSpaceNode.js';
import NormalMapNode from './display/NormalMapNode.js';

// math
import MathNode from './math/MathNode.js';
import OperatorNode from './math/OperatorNode.js';

// lights
import LightContextNode from './lights/LightContextNode.js';
import LightNode from './lights/LightNode.js';
import LightsNode from './lights/LightsNode.js';

// utils
import ArrayElementNode from './utils/ArrayElementNode.js';
import ConvertNode from './utils/ConvertNode.js';
import JoinNode from './utils/JoinNode.js';
import SplitNode from './utils/SplitNode.js';
import SpriteSheetUVNode from './utils/SpriteSheetUVNode.js';
import OscNode from './utils/OscNode.js';
import TimerNode from './utils/TimerNode.js';

// procedural
import CheckerNode from './procedural/CheckerNode.js';

// core
export * from './core/constants.js';

// functions
export * from './functions/BSDFs.js';

// materials
export * from './materials/Materials.js';

// shader node
export * from './ShaderNode.js';

export {
	// core
	ArrayInputNode,
	AttributeNode,
	BypassNode,
	CodeNode,
	ContextNode,
	ExpressionNode,
	FunctionCallNode,
	FunctionNode,
	InputNode,
	Node,
	NodeAttribute,
	NodeBuilder,
	NodeCode,
	NodeFrame,
	NodeFunctionInput,
	NodeKeywords,
	NodeUniform,
	NodeVar,
	NodeVary,
	PropertyNode,
	TempNode,
	VarNode,
	VaryNode,

	// accessors
	CameraNode,
	MaterialNode,
	MaterialReferenceNode,
	ModelNode,
	ModelViewProjectionNode,
	NormalNode,
	Object3DNode,
	PointUVNode,
	PositionNode,
	ReferenceNode,
	SkinningNode,
	UVNode,

	// inputs
	ColorNode,
	FloatNode,
	IntNode,
	Matrix3Node,
	Matrix4Node,
	TextureNode,
	Vector2Node,
	Vector3Node,
	Vector4Node,

	// display
	ColorSpaceNode,
	NormalMapNode,

	// math
	MathNode,
	OperatorNode,

	// lights
	LightContextNode,
	LightNode,
	LightsNode,

	// utils
	ArrayElementNode,
	JoinNode,
	SplitNode,
	SpriteSheetUVNode,
	OscNode,
	TimerNode,

	// procedural
	CheckerNode
};
